@@ -51,16 +51,13 @@
 #define ECONNREFUSED 107
 #endif
 
-#include <unistd.h>
-#include <signal.h>
-
-#ifdef WIN32
+#ifdef _WIN32
 #include <winsock2.h>
 #include <windows.h>
-#ifndef HAVE_SLEEP
 #define sleep(x) Sleep(x*1000)
-#endif
 #else
+#include <unistd.h>
+#include <signal.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #if defined(HAVE_PROGRAM_INVOCATION_SHORT_NAME) && !defined(HAVE_PROGRAM_INVOCATION_SHORT_NAME_ERRNO_H)
@@ -93,8 +90,11 @@ static char* stpncpy(char *dst, const char *src, size_t len)
 }
 #endif
 
+#ifdef _MSC_VER
+#define strcasecmp _stricmp
+#endif
+
 #include <plist/plist.h>
-#define PLIST_CLIENT_VERSION_STRING PACKAGE_STRING
 #define PLIST_LIBUSBMUX_VERSION 3
 
 static char *bundle_id = NULL;
@@ -115,6 +115,9 @@ static int libusbmuxd_debug = 0;
 #ifndef PACKAGE
 #define PACKAGE "libusbmuxd"
 #endif
+#ifndef PACKAGE_NAME
+#define PACKAGE_NAME PACKAGE
+#endif
 #define LIBUSBMUXD_DEBUG(level, format, ...) if (level <= libusbmuxd_debug) fprintf(stderr, ("[" PACKAGE "] " format), __VA_ARGS__); fflush(stderr);
 #define LIBUSBMUXD_ERROR(format, ...) LIBUSBMUXD_DEBUG(0, format, __VA_ARGS__)
 
@@ -164,7 +167,7 @@ static int connect_usbmuxd_socket()
 	char *usbmuxd_socket_addr = getenv("USBMUXD_SOCKET_ADDRESS");
 	if (usbmuxd_socket_addr) {
 		if (strncmp(usbmuxd_socket_addr, "UNIX:", 5) == 0) {
-#if defined(WIN32) || defined(__CYGWIN__)
+#if defined(_WIN32) || defined(__CYGWIN__)
 			/* not supported, ignore */
 #else
 			if (usbmuxd_socket_addr[5] != '\0') {
@@ -215,7 +218,7 @@ static int connect_usbmuxd_socket()
 			}
 		}
 	}
-#if defined(WIN32) || defined(__CYGWIN__)
+#if defined(_WIN32) || defined(__CYGWIN__)
 	res = socket_connect("127.0.0.1", USBMUXD_SOCKET_PORT);
 #else
 	res = socket_connect_unix(USBMUXD_SOCKET_FILE);
@@ -660,7 +663,7 @@ static void get_prog_name()
 	if (pname) {
 		prog_name = strdup(pname);
 	}
-#elif defined (WIN32)
+#elif defined (_WIN32)
 	TCHAR *_pname = malloc((MAX_PATH+1) * sizeof(TCHAR));
 	if (GetModuleFileName(NULL, _pname, MAX_PATH+1) > 0) {
 		char* pname = NULL;
@@ -721,6 +724,8 @@ static void get_prog_name()
 
 static plist_t create_plist_message(const char* message_type)
 {
+	char client_version[128];
+	snprintf(client_version, 128, PACKAGE_NAME " %s", libusbmuxd_version());
 	if (!bundle_id) {
 		get_bundle_id();
 	}
@@ -731,7 +736,7 @@ static plist_t create_plist_message(const char* message_type)
 	if (bundle_id) {
 		plist_dict_set_item(plist, "BundleID", plist_new_string(bundle_id));
 	}
-	plist_dict_set_item(plist, "ClientVersionString", plist_new_string(PLIST_CLIENT_VERSION_STRING));
+	plist_dict_set_item(plist, "ClientVersionString", plist_new_string(client_version));
 	plist_dict_set_item(plist, "MessageType", plist_new_string(message_type));
 	if (prog_name) {
 		plist_dict_set_item(plist, "ProgName", plist_new_string(prog_name));
@@ -1593,7 +1598,7 @@ int usbmuxd_send(int sfd, const char *data, uint32_t len, uint32_t *sent_bytes)
 	if (num_sent < 0) {
 		*sent_bytes = 0;
 		LIBUSBMUXD_DEBUG(1, "%s: Error %d when sending: %s\n", __func__, -num_sent, strerror(-num_sent));
-		return -num_sent;
+		return num_sent;
 	}
 
 	if ((uint32_t)num_sent < len) {
