@@ -32,20 +32,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <fcntl.h>
 #include <stddef.h>
-#include <unistd.h>
 #include <errno.h>
-#include <getopt.h>
-#ifdef WIN32
+
+#ifdef _WIN32
 #include <winsock2.h>
 #include <windows.h>
 typedef unsigned int socklen_t;
 #else
+#include <fcntl.h>
+#include <unistd.h>
 #include <sys/select.h>
 #include <sys/socket.h>
 #include <signal.h>
 #endif
+
+#include <getopt.h>
 #include <libimobiledevice-glue/socket.h>
 #include <libimobiledevice-glue/thread.h>
 #include "usbmuxd.h"
@@ -156,6 +158,9 @@ static void *acceptor_thread(void *arg)
 		}
 		fprintf(stdout, "Requesting connection to NETWORK device %s (serial: %s), port %d\n", addrtxt, dev->udid, cdata->device_port);
 		cdata->sfd = socket_connect_addr(saddr, cdata->device_port);
+		if (cdata->sfd < 0) {
+			cdata->sfd = -errno;
+		}
 	} else if (dev->conn_type == CONNECTION_TYPE_USB) {
 		fprintf(stdout, "Requesting connection to USB device handle %d (serial: %s), port %d\n", dev->handle, dev->udid, cdata->device_port);
 
@@ -163,16 +168,17 @@ static void *acceptor_thread(void *arg)
 	}
 	free(dev_list);
 	if (cdata->sfd < 0) {
-		fprintf(stderr, "Error connecting to device: %s\n", strerror(errno));
+		fprintf(stderr, "Error connecting to device: %s\n", strerror(-cdata->sfd));
 	} else {
 		fd_set fds;
 		FD_ZERO(&fds);
 		FD_SET(cdata->fd, &fds);
 		FD_SET(cdata->sfd, &fds);
+		int maxfd = cdata->fd > cdata->sfd ? cdata->fd : cdata->sfd;
 
 		while (1) {
 			fd_set read_fds = fds;
-			int ret_sel = select(cdata->sfd+1, &read_fds, NULL, NULL, NULL);
+			int ret_sel = select(maxfd+1, &read_fds, NULL, NULL, NULL);
 			if (ret_sel < 0) {
 				perror("select");
 				break;
@@ -300,7 +306,7 @@ int main(int argc, char **argv)
 			print_usage(argc, argv, 0);
 			return 0;
 		case 'v':
-			printf("%s %s\n", TOOL_NAME, PACKAGE_VERSION);
+			printf("%s %s\n", TOOL_NAME, libusbmuxd_version());
 			return 0;
 		default:
 			print_usage(argc, argv, 1);
@@ -331,7 +337,7 @@ int main(int argc, char **argv)
 			fprintf(stderr, "Invalid listen port specified in argument '%s'!\n", argv[0]);
 			free(device_udid);
 			free(source_addr);
-			return -EINVAL;
+			return EINVAL;
 		}
 		endp = NULL;
 		device_port[0] = (uint16_t)strtol(argv[1], &endp, 10);
@@ -339,7 +345,7 @@ int main(int argc, char **argv)
 			fprintf(stderr, "Invalid device port specified in argument '%s'!\n", argv[1]);
 			free(device_udid);
 			free(source_addr);
-			return -EINVAL;
+			return EINVAL;
 		}
 		num_pairs = 1;
 	} else {
@@ -351,14 +357,14 @@ int main(int argc, char **argv)
 				fprintf(stderr, "Invalid listen port specified in argument '%s'!\n", argv[i]);
 				free(device_udid);
 				free(source_addr);
-				return -EINVAL;
+				return EINVAL;
 			}
 			device_port[i] = (uint16_t)strtol(endp+1, &endp, 10);
 			if (!device_port[i] || (*endp != '\0')) {
 				fprintf(stderr, "Invalid device port specified in argument '%s'!\n", argv[i+1]);
 				free(device_udid);
 				free(source_addr);
-				return -EINVAL;
+				return EINVAL;
 			}
 		}
 		num_pairs = argc;
@@ -366,10 +372,10 @@ int main(int argc, char **argv)
 
 	if (num_pairs > 16) {
 		fprintf(stderr, "ERROR: Too many LOCAL:DEVICE port pairs. Maximum is 16.\n");
-		return -1;
+		return 1;
 	}
 
-#ifndef WIN32
+#ifndef _WIN32
 	signal(SIGPIPE, SIG_IGN);
 #endif
 
@@ -386,7 +392,7 @@ int main(int argc, char **argv)
 				for (j = num_listen; j >= 0; j--) {
 					socket_close(listen_sock[j].fd);
 				}
-				return -errno;
+				return 1;
 			}
 			listen_sock[num_listen].index = i;
 			num_listen++;
@@ -400,7 +406,7 @@ int main(int argc, char **argv)
 				for (j = num_listen; j >= 0; j--) {
 					socket_close(listen_sock[j].fd);
 				}
-				return -errno;
+				return 1;
 			}
 			listen_sock[num_listen].index = i;
 			num_listen++;
@@ -411,7 +417,7 @@ int main(int argc, char **argv)
 	fd_set fds;
 	FD_ZERO(&fds);
 	for (i = 0; i < num_listen; i++) {
-#ifdef WIN32
+#ifdef _WIN32
 		u_long l_yes = 1;
 		ioctlsocket(listen_sock[i].fd, FIONBIO, &l_yes);
 #else
@@ -445,7 +451,7 @@ int main(int argc, char **argv)
 					socket_close(c_sock);
 					fprintf(stderr, "ERROR: Out of memory\n");
 					free(device_udid);
-					return -1;
+					return 1;
 				}
 				cdata->fd = c_sock;
 				cdata->sfd = -1;
